@@ -1,5 +1,5 @@
 /*
-//@line 38 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/addonManager.js"
+//@line 38 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/addonManager.js"
 */
 
 /**
@@ -8,6 +8,8 @@
  * as passing new installs from webpages to the AddonManager.
  */
 
+"use strict";
+
 const Cc = Components.classes;
 const Ci = Components.interfaces;
 const Cr = Components.results;
@@ -104,18 +106,18 @@ amManager.prototype = {
       }
       let uri = aUris.shift();
       AddonManager.getInstallForURL(uri, function(aInstall) {
+        function callCallback(aUri, aStatus) {
+          try {
+            aCallback.onInstallEnded(aUri, aStatus);
+          }
+          catch (e) {
+            Components.utils.reportError(e);
+          }
+        }
+
         if (aInstall) {
           installs.push(aInstall);
           if (aCallback) {
-            function callCallback(aUri, aStatus) {
-              try {
-                aCallback.onInstallEnded(aUri, aStatus);
-              }
-              catch (e) {
-                Components.utils.reportError(e);
-              }
-            }
-
             aInstall.addListener({
               onDownloadCancelled: function(aInstall) {
                 callCallback(uri, USER_CANCELLED);
