@@ -1,4 +1,4 @@
-//@line 40 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/components/viewconfig/content/config.js"
+//@line 40 "/builds/slave/m-beta-lnx-xr/build/toolkit/components/viewconfig/content/config.js"
 
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString = Components.interfaces.nsISupportsString;
@@ -381,8 +381,9 @@ function ShowPrefs()
 
   // Process about:config?filter=<string>
   var textbox = document.getElementById("textbox");
-  var uri = document.documentURIObject;
-  var matches = /[?&]filter\=([^&]+)/i.exec(uri.path);
+  // About URIs don't support query params, so do this manually
+  var loc = document.location.href;
+  var matches = /[?&]filter\=([^&]+)/i.exec(loc);
   if (matches)
     textbox.value = decodeURIComponent(matches[1]);
 
@@ -569,7 +570,12 @@ function NewPref(type)
                             gConfigBundle.getString("new_prompt"),
                             result,
                             null,
-                            dummy) && result.value) {
+                            dummy)) {
+    result.value = result.value.trim();
+    if (!result.value) {
+      return;
+    }
+
     var pref;
     if (result.value in gPrefHash)
       pref = gPrefHash[result.value];
