@@ -1,4 +1,6 @@
-//@line 37 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
