@@ -1,4 +1,4 @@
-//@line 37 "/builds/slave/m-beta-linuxqt-xr/build/toolkit/mozapps/extensions/content/selectAddons.js"
+//@line 37 "/builds/slave/m-beta-lnx-xr/build/toolkit/mozapps/extensions/content/selectAddons.js"
 
 "use strict";
 
@@ -45,13 +45,7 @@ function isAddonDistroInstalled(aID) {
 }
 
 function orderForScope(aScope) {
-  switch (aScope) {
-  case AddonManager.SCOPE_PROFILE:
-  case AddonManager.SCOPE_APPLICATION:
-    return 1;
-  default:
-    return 0;
-  }
+  return aScope == AddonManager.SCOPE_PROFILE ? 1 : 0;
 }
 
 var gAddons = {};
